%define major	0
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

Name:		p11-kit
Summary:	Load and enumerate PKCS#11 modules
Version:	0.23.2
Release:	%mkrel 2

Group:		System/Libraries
Url:		http://p11-glue.freedesktop.org/p11-kit.html
Source0:	http://p11-glue.freedesktop.org/releases/%{name}-%{version}.tar.gz
License:	Apache License
BuildRequires:	pkgconfig(libtasn1)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(gtk-doc)

%description
Provides a way to load and enumerate PKCS#11 modules. Provides a standard
configuration setup for installing PKCS#11 modules in such a way that
they're discoverable.

Also solves problems with coordinating the use of PKCS#11 by different
components or libraries living in the same process.

%package -n %{libname}
Summary:	Library and proxy module for properly loading and sharing PKCS#11 modules
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}

%description -n %{libname}
Provides a way to load and enumerate PKCS#11 modules. Provides a standard
configuration setup for installing PKCS#11 modules in such a way that
they're discoverable.

Also solves problems with coordinating the use of PKCS#11 by different
components or libraries living in the same process.

%package -n %{devname}
Summary:	Development files and headers for %{name}
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains the development files and headers for %{name}.

%package        trust
Summary:        System trust module from %{name}
Requires:	%{name} = %{version}-%{release}

%description    trust
The %{name}-trust package contains a system trust PKCS#11 module which
contains certificate anchors and black lists.

%prep
%setup -q
%autopatch -p1

%build
%configure2_5x \
	--disable-static \
	--disable-rpath \
	--enable-doc
%make_build

%install
%make_install

#dirs for configs etc
mkdir -p %{buildroot}%{_sysconfdir}/pkcs11/modules

# install the example config file as config file (mga #12696)
mv %{buildroot}%{_sysconfdir}/pkcs11/pkcs11.conf.example %{buildroot}%{_sysconfdir}/pkcs11/pkcs11.conf

# we don't want these
find %{buildroot} -name "*.la" -exec rm -rf {} \;

# Disable for now as it fails on 32-bit
# Need more investigation and a fix
#%%check
#%%make_build check

# remove invalid empty config file installed by default until p11-kit-0.20.1-3 (mga #12696)
%pretrans -p <lua>

file = io.open("/etc/pkcs11/pkcs11.conf","r")

if (file) then
  size = file:seek("end")
  file:close()
  if (size == 0) then
    os.remove("/etc/pkcs11/pkcs11.conf")
  end
end

%files
%doc p11-kit/pkcs11.conf.example
%{_bindir}/%{name}
%dir %{_sysconfdir}/pkcs11
%dir %{_sysconfdir}/pkcs11/modules
%config(noreplace) %{_sysconfdir}/pkcs11/pkcs11.conf
%dir %{_libdir}/p11-kit
%dir %{_datadir}/p11-kit
%dir %{_datadir}/p11-kit/modules
%{_mandir}/man?/%{name}.*.*
%{_mandir}/man?/pkcs11.conf.*.*
%{_libdir}/p11-kit/p11-kit-remote

%files -n %{libname}
%doc AUTHORS NEWS
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{devname}
%doc %{_datadir}/gtk-doc/html/%{name}
%{_includedir}/%{name}-1
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}-1.pc

%files trust
%{_bindir}/trust
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/p11-kit-trust.so
%{_datadir}/p11-kit/modules/p11-kit-trust.module
%{_libdir}/p11-kit/trust-extract-compat
%{_mandir}/man?/trust.*.*


%changelog
* Fri May 13 2016 daviddavid <daviddavid> 0.23.2-2.mga6
+ Revision: 1015053
- use std build macros; prevent commented out macros to break build

* Mon Jan 11 2016 luigiwalser <luigiwalser> 0.23.2-1.mga6
+ Revision: 921782
- 0.23.2 (needed for gnutls 3.4)

* Fri Aug 21 2015 tmb <tmb> 0.22.1-2.mga6
+ Revision: 867671
- rebuild for new gcc

* Sun Jun 21 2015 ovitters <ovitters> 0.22.1-1.mga6
+ Revision: 837842
- new version 0.22.1

* Wed Oct 15 2014 umeabot <umeabot> 0.20.6-6.mga5
+ Revision: 748305
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 0.20.6-5.mga5
+ Revision: 737755
- keep %%pretrans but use lua for scriptlet

* Thu Oct 09 2014 tv <tv> 0.20.6-4.mga5
+ Revision: 737743
- do not use %%pretrans when %%pre is enough;
  this add a "interp,pretrans: /bin/sh" dep which breaks installer first transaction

* Fri Oct 03 2014 tmb <tmb> 0.20.6-3.mga5
+ Revision: 736547
- rebuild for /bin/sh dep

* Tue Sep 16 2014 umeabot <umeabot> 0.20.6-2.mga5
+ Revision: 683300
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 luigiwalser <luigiwalser> 0.20.6-1.mga5
+ Revision: 674245
- 0.20.6

* Fri Sep 05 2014 luigiwalser <luigiwalser> 0.20.5-1.mga5
+ Revision: 672267
- 0.20.5

* Sat Aug 16 2014 luigiwalser <luigiwalser> 0.20.4-1.mga5
+ Revision: 664087
- 0.20.4

* Thu Jul 10 2014 luigiwalser <luigiwalser> 0.20.3-1.mga5
+ Revision: 651145
- 0.20.3
- remove upstreamed patch

* Sat Feb 15 2014 luigiwalser <luigiwalser> 0.20.2-1.mga5
+ Revision: 591480
- 0.20.2
- Own the %%{_libdir}/pkcs11 dir in -trust

* Wed Feb 12 2014 lmenut <lmenut> 0.20.1-6.mga5
+ Revision: 589908
- remove requires to rpm-helper after posttrans removal

* Tue Feb 11 2014 lmenut <lmenut> 0.20.1-5.mga5
+ Revision: 589572
- install valid pkcs11.conf (mga#12696)
  + remove invalid empty config file in pretrans
  + install uptream example config as default config

* Mon Feb 10 2014 pterjan <pterjan> 0.20.1-4.mga5
+ Revision: 587833
- Fix handling of mmap failure

* Tue Oct 29 2013 tv <tv> 0.20.1-3.mga4
+ Revision: 547769
- move rpm-helper %%post in %%posttrans (trying to fix install deps loop errors)

* Sat Oct 19 2013 umeabot <umeabot> 0.20.1-2.mga4
+ Revision: 535052
- Mageia 4 Mass Rebuild

* Tue Sep 17 2013 dams <dams> 0.20.1-1.mga4
+ Revision: 480854
- disable %%check for now as it fails in 32-bit
- new version 0.20.1
- enable man page

* Tue Jul 23 2013 luigiwalser <luigiwalser> 0.18.5-1.mga4
+ Revision: 457503
- 0.18.5

* Sun May 26 2013 blino <blino> 0.18.2-1.mga4
+ Revision: 428249
- buildrequire pkgconfig(libtasn1)
- package trust module in a subpackage
- 0.18.2

* Sun Jan 13 2013 umeabot <umeabot> 0.14-2.mga3
+ Revision: 362317
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 16 2012 fwang <fwang> 0.14-1.mga3
+ Revision: 294398
- new version 0.14

* Mon Jul 16 2012 wally <wally> 0.13-1.mga3
+ Revision: 271336
- new version 0.13

* Tue May 29 2012 dams <dams> 0.12-1.mga3
+ Revision: 249107
- new version 0.12
- add a 'requires(post)' on 'rpm-helper'

* Fri Feb 10 2012 wally <wally> 0.11-1.mga2
+ Revision: 206898
- new version 0.11

* Tue Jan 03 2012 wally <wally> 0.10-1.mga2
+ Revision: 189984
- new version 0.10

* Thu Nov 17 2011 wally <wally> 0.9-1.mga2
+ Revision: 168377
- new version 0.9

* Thu Oct 27 2011 wally <wally> 0.8-1.mga2
+ Revision: 158797
- new version 0.8

* Wed Sep 28 2011 wally <wally> 0.7-1.mga2
+ Revision: 149934
- new version 0.7

* Fri Sep 16 2011 wally <wally> 0.6-1.mga2
+ Revision: 144292
- new version 0.6

* Mon Sep 05 2011 wally <wally> 0.5-1.mga2
+ Revision: 138880
- new version 0.5
- new version 0.4
- make devel package require the lib one
- fix requires
- imported package p11-kit

  + fwang <fwang>
    - new version 0.3

